@@ -22,6 +22,7 @@
 """Formats docstrings to follow PEP 257."""
 
 from __future__ import print_function
+from __future__ import unicode_literals
 
 import io
 import os
@@ -29,7 +30,7 @@ import re
 import tokenize
 
 
-__version__ = '0.3'
+__version__ = '0.3.1'
 
 
 try:
@@ -161,14 +162,14 @@ def format_docstring(indentation, docstring,
 {description}{post_description}
 {indentation}"""\
 '''.format(pre_summary=('\n' + indentation if pre_summary_newline
-                        else unicode()),
+                        else ''),
            summary=wrap_summary(normalize_summary(summary),
                                 wrap_length=summary_wrap_length,
                                 initial_indent=initial_indent,
                                 subsequent_indent=indentation).lstrip(),
            description='\n'.join([indent_non_indented(l, indentation).rstrip()
                                   for l in description.splitlines()]),
-           post_description=('\n' if post_description_blank else unicode()),
+           post_description=('\n' if post_description_blank else ''),
            indentation=indentation)
     else:
         return wrap_summary('"""' + normalize_summary(contents) + '"""',
@@ -185,6 +186,12 @@ def indent_non_indented(line, indentation):
         return line
 
 
+def is_probably_beginning_of_sentence(line):
+    """Return True if this line begins a new sentence."""
+    character = line.strip()[0]
+    return character.isupper() or not character.isalnum()
+
+
 def split_summary_and_description(contents):
     """Split docstring into summary and description.
 
@@ -195,14 +202,18 @@ def split_summary_and_description(contents):
     if len(split) > 1 and not split[1].strip():
         # Empty line separation would indicate the rest is the description.
         return (split[0], '\n'.join(split[2:]))
-    elif len(split) > 1 and not split[1].strip()[0].isalnum():
+    elif len(split) > 1 and is_probably_beginning_of_sentence(split[1]):
         # Symbol on second line probably is a description with a list.
         return (split[0], '\n'.join(split[1:]))
     else:
         # Break on first sentence.
-        split = re.split(r'\.\s', string=contents, maxsplit=1)
-        if len(split) == 2:
-            return (split[0].strip() + '.', split[1].strip())
+        for punctuation in '.?!:':
+            split = re.split('\\' + punctuation + r'\s',
+                             string=contents,
+                             maxsplit=1)
+            if len(split) == 2:
+                return (split[0].strip() + punctuation,
+                        split[1].strip())
 
         # Break on first bullet-list-like text.
         for token in ['    @',
@@ -212,7 +223,7 @@ def split_summary_and_description(contents):
             if len(split) == 2:
                 return (split[0].strip(), (token + split[1]).strip())
 
-    return (split[0].strip(), unicode())
+    return (split[0].strip(), '')
 
 
 def strip_docstring(docstring):
@@ -296,7 +307,7 @@ def format_file(filename, args, standard_out):
                 'before/' + filename,
                 'after/' + filename,
                 lineterm='')
-            standard_out.write(unicode('\n').join(list(diff) + ['']))
+            standard_out.write('\n'.join(list(diff) + ['']))
 
 
 def main(argv, standard_out, standard_error):
